from stripe.api_resources.issuing.authorization import Authorization as Authorization
from stripe.api_resources.issuing.card import Card as Card
from stripe.api_resources.issuing.card_details import CardDetails as CardDetails
from stripe.api_resources.issuing.cardholder import Cardholder as Cardholder
from stripe.api_resources.issuing.dispute import Dispute as Dispute
from stripe.api_resources.issuing.transaction import Transaction as Transaction



from collections.abc import Iterator
from typing import Any

from stripe import api_requestor as api_requestor
from stripe.api_resources.abstract.api_resource import APIResource as APIResource
from stripe.api_resources.list_object import ListObject

class ListableAPIResource(APIResource):
    @classmethod
    def auto_paging_iter(cls, *args, **params) -> Iterator[Any]: ...
    @classmethod
    def list(
        cls, api_key: Any | None = ..., stripe_version: Any | None = ..., stripe_account: Any | None = ..., **params
    ) -> ListObject: ...



from typing import Any

from stripe import api_requestor as api_requestor
from stripe.api_resources.abstract import ListableAPIResource as ListableAPIResource

class File(ListableAPIResource):
    OBJECT_NAME: str
    OBJECT_NAME_ALT: str
    @classmethod
    def class_url(cls): ...
    @classmethod
    def create(
        cls,
        api_key: Any | None = ...,
        api_version: Any | None = ...,
        stripe_version: Any | None = ...,
        stripe_account: Any | None = ...,
        **params,
    ): ...

FileUpload = File



from stripe.api_resources.abstract import (
    CreateableAPIResource as CreateableAPIResource,
    DeletableAPIResource as DeletableAPIResource,
    ListableAPIResource as ListableAPIResource,
    UpdateableAPIResource as UpdateableAPIResource,
    nested_resource_class_methods as nested_resource_class_methods,
)

class SubscriptionItem(CreateableAPIResource, DeletableAPIResource, ListableAPIResource, UpdateableAPIResource):
    OBJECT_NAME: str
    def usage_record_summaries(self, **params): ...
    @classmethod
    def usage_records_url(cls, id, nested_id=...): ...
    @classmethod
    def usage_records_request(
        cls, method, url, api_key=..., idempotency_key=..., stripe_version=..., stripe_account=..., **params
    ): ...
    @classmethod
    def create_usage_record(cls, id, **params): ...
    @classmethod
    def usage_record_summarys_url(cls, id, nested_id=...): ...
    @classmethod
    def usage_record_summarys_request(
        cls, method, url, api_key=..., idempotency_key=..., stripe_version=..., stripe_account=..., **params
    ): ...
    @classmethod
    def list_usage_record_summaries(cls, id, **params): ...



from stripe.api_resources.abstract import (
    CreateableAPIResource as CreateableAPIResource,
    DeletableAPIResource as DeletableAPIResource,
    ListableAPIResource as ListableAPIResource,
)

class ValueListItem(CreateableAPIResource, DeletableAPIResource, ListableAPIResource):
    OBJECT_NAME: str



from typing import Any

from stripe import error as error
from stripe.request_metrics import RequestMetrics as RequestMetrics

version: Any
major: Any
minor: Any
patch: Any

def new_default_http_client(*args, **kwargs): ...

class HTTPClient:
    MAX_DELAY: int
    INITIAL_DELAY: float
    MAX_RETRY_AFTER: int
    def __init__(self, verify_ssl_certs: bool = ..., proxy: Any | None = ...) -> None: ...
    def request_with_retries(self, method, url, headers, post_data: Any | None = ...): ...
    def request_stream_with_retries(self, method, url, headers, post_data: Any | None = ...): ...
    def request(self, method, url, headers, post_data: Any | None = ...) -> None: ...
    def request_stream(self, method, url, headers, post_data: Any | None = ...) -> None: ...
    def close(self) -> None: ...

class RequestsClient(HTTPClient):
    name: str
    def __init__(self, timeout: int = ..., session: Any | None = ..., **kwargs) -> None: ...
    def request(self, method, url, headers, post_data: Any | None = ...): ...
    def request_stream(self, method, url, headers, post_data: Any | None = ...): ...
    def close(self) -> None: ...

class UrlFetchClient(HTTPClient):
    name: str
    def __init__(self, verify_ssl_certs: bool = ..., proxy: Any | None = ..., deadline: int = ...) -> None: ...
    def request(self, method, url, headers, post_data: Any | None = ...): ...
    def request_stream(self, method, url, headers, post_data: Any | None = ...): ...
    def close(self) -> None: ...

class PycurlClient(HTTPClient):
    name: str
    def __init__(self, verify_ssl_certs: bool = ..., proxy: Any | None = ...) -> None: ...
    def parse_headers(self, data): ...
    def request(self, method, url, headers, post_data: Any | None = ...): ...
    def request_stream(self, method, url, headers, post_data: Any | None = ...): ...
    def close(self) -> None: ...

class Urllib2Client(HTTPClient):
    name: str
    def __init__(self, verify_ssl_certs: bool = ..., proxy: Any | None = ...) -> None: ...
    def request(self, method, url, headers, post_data: Any | None = ...): ...
    def request_stream(self, method, url, headers, post_data: Any | None = ...): ...
    def close(self) -> None: ...



from typing import Any

from stripe.api_resources.abstract import ListableAPIResource as ListableAPIResource, custom_method as custom_method

class Review(ListableAPIResource):
    OBJECT_NAME: str
    def approve(self, idempotency_key: Any | None = ..., **params): ...



from stripe.api_resources.abstract import (
    CreateableAPIResource as CreateableAPIResource,
    ListableAPIResource as ListableAPIResource,
    UpdateableAPIResource as UpdateableAPIResource,
)

class Cardholder(CreateableAPIResource, ListableAPIResource, UpdateableAPIResource):
    OBJECT_NAME: str



from typing import Any

from stripe import oauth as oauth
from stripe.api_resources.abstract import (
    CreateableAPIResource as CreateableAPIResource,
    DeletableAPIResource as DeletableAPIResource,
    ListableAPIResource as ListableAPIResource,
    UpdateableAPIResource as UpdateableAPIResource,
    custom_method as custom_method,
    nested_resource_class_methods as nested_resource_class_methods,
)

class Account(CreateableAPIResource, DeletableAPIResource, ListableAPIResource):
    OBJECT_NAME: str
    def reject(self, idempotency_key: Any | None = ..., **params): ...
    @classmethod
    def retrieve(cls, id: Any | None = ..., api_key: Any | None = ..., **params): ...
    @classmethod
    def modify(cls, id: Any | None = ..., **params): ...
    def instance_url(self): ...
    def persons(self, **params): ...
    def deauthorize(self, **params): ...
    def serialize(self, previous): ...
    @classmethod
    def capabilitys_url(cls, id, nested_id=...): ...
    @classmethod
    def capabilitys_request(
        cls, method, url, api_key=..., idempotency_key=..., stripe_version=..., stripe_account=..., **params
    ): ...
    @classmethod
    def retrieve_capability(cls, id, nested_id, **params): ...
    @classmethod
    def modify_capability(cls, id, nested_id, **params): ...
    @classmethod
    def list_capabilities(cls, id, **params): ...
    @classmethod
    def external_accounts_url(cls, id, nested_id=...): ...
    @classmethod
    def external_accounts_request(
        cls, method, url, api_key=..., idempotency_key=..., stripe_version=..., stripe_account=..., **params
    ): ...
    @classmethod
    def create_external_account(cls, id, **params): ...
    @classmethod
    def retrieve_external_account(cls, id, nested_id, **params): ...
    @classmethod
    def modify_external_account(cls, id, nested_id, **params): ...
    @classmethod
    def delete_external_account(cls, id, nested_id, **params): ...
    @classmethod
    def list_external_accounts(cls, id, **params): ...
    @classmethod
    def login_links_url(cls, id, nested_id=...): ...
    @classmethod
    def login_links_request(
        cls, method, url, api_key=..., idempotency_key=..., stripe_version=..., stripe_account=..., **params
    ): ...
    @classmethod
    def create_login_link(cls, id, **params): ...
    @classmethod
    def persons_url(cls, id, nested_id=...): ...
    @classmethod
    def persons_request(cls, method, url, api_key=..., idempotency_key=..., stripe_version=..., stripe_account=..., **params): ...
    @classmethod
    def create_person(cls, id, **params): ...
    @classmethod
    def retrieve_person(cls, id, nested_id, **params): ...
    @classmethod
    def modify_person(cls, id, nested_id, **params): ...
    @classmethod
    def delete_person(cls, id, nested_id, **params): ...
    @classmethod
    def list_persons(cls, id, **params): ...



from _typeshed import Self
from typing import Any, NoReturn

from stripe.api_resources import ApplicationFee as ApplicationFee
from stripe.api_resources.abstract import UpdateableAPIResource as UpdateableAPIResource

class ApplicationFeeRefund(UpdateableAPIResource):
    OBJECT_NAME: str
    @classmethod
    def modify(cls: type[Self], fee, sid: str, **params) -> Self: ...  # type: ignore[override]
    def instance_url(self) -> str: ...
    @classmethod
    def retrieve(cls, id, api_key: Any | None = ..., **params) -> NoReturn: ...
